@@ -360,7 +360,7 @@ class MObject(object):
                     if not self._m__delta['$unset']:
                         del self._m__delta['$unset']
 
-    def __getattr__(self, k, raw=False, default=None):
+    def __getattr__(self, k, raw=False, use_default=True):
         if k.startswith('_m__'):
             return self.__dict__[k]
 
@@ -377,13 +377,13 @@ class MObject(object):
             elif k in self.BELONGS_TO_MANY and (k not in self._m__relations or not isinstance(self._m__relations[k], BelongsToMany)):
                 self._m__relations[k] = BelongsToMany.load(self, k, self.BELONGS_TO_MANY[k])
 
-        if k in self.DEFAULT_VALUES and default is None:
-            default = self.DEFAULT_VALUES[k]
-
         if not raw and k in self._m__relations:
             val = self._m__relations[k]
         else:
-            val = self._m__data.get(k, default)
+            if use_default and k in self.DEFAULT_VALUES:
+                val = self._m__data.get(k, self.DEFAULT_VALUES[k])
+            else:
+                val = self._m__data[k]
 
         if isinstance(val, list):
             val = MList(val, self, k)
@@ -392,6 +392,36 @@ class MObject(object):
 
         return val
 
+    def get(self, k, default=None, raw=True):
+        try:
+            r = self.__getattr__(k, raw=raw, use_default=False)
+        except:
+            r = default
+        return r
+
+    def inc(self, k, v=1):
+        if k in self.BELONGS_TO_MANY or k in self.HAS_MANY or k in self.BELONGS_TO:
+            raise KeyError('{0} is a relationship. Not a value.'.format(k))
+
+        start_val = self.get(k, 0)
+        if not isinstance(start_val, (int, float, long, complex)):
+            raise TypeError('{0} must be a number to increment'.format(k))
+        new_val = start_val + v
+
+        self._m__data[k] = new_val
+
+        if not self._m__is_new:
+            i = v
+            if '$set' in self._m__delta and k in self._m__delta['$set']:
+                i += self._m__delta['$set'][k]
+                del self._m__delta['$set'][k]
+
+            if '$inc' not in self._m__delta:
+                self._m__delta['$inc'] = {}
+            self._m__delta['$inc'][k] = i
+
+        return new_val
+
     def rawdata(self):
         ''' Returns the real data that the model contains.
         
