@@ -52,7 +52,7 @@ class _Relationship(object):
             value = active
             for _key in key2.split('.'):
                 if hasattr(value, 'COLLECTION'):
-                    value = value.__getattr__(_key, raw=True, default=[] if cls.TYPE == cls.BELONGS_TO_MANY else '')
+                    value = value.get(_key, default=[] if cls.TYPE == cls.BELONGS_TO_MANY else '', raw=True)
                 else:
                     value = value.get(_key)
             if cls.TYPE == cls.BELONGS_TO_MANY:
@@ -198,7 +198,7 @@ class BelongsToMany(_Relationship, _Multi):
         if not isinstance(val, PRIMITIVES):
             val = val.__getattr__(self._rel__foreign_key, raw=True)
 
-        fin = self._rel__active.__getattr__(self._rel__key, raw=True, default=[])
+        fin = self._rel__active.get(self._rel__key, default=[], raw=True)
         fin.append(val)
         setattr(self._rel__active, self._rel__key, fin)
         # TODO: add to self._data (cursor)
@@ -215,7 +215,7 @@ class BelongsToMany(_Relationship, _Multi):
         if not isinstance(val, PRIMITIVES):
             val = val.__getattr__(self._rel__foreign_key, raw=True)
 
-        fin = self._rel__active.__getattr__(self._rel__key, raw=True, default=[])
+        fin = self._rel__active.get(self._rel__key, default=[], raw=True)
         if val in fin:
             fin = [x for x in fin if x != val]
             setattr(self._rel__active, self._rel__key, fin)
